@@ -24,13 +24,11 @@
 #include <hildon/hildon.h>
 #include <hildon/hildon-calendar-popup.h>
 #include <hildon/hildon-color-button.h>
-#if 0
-G_BEGIN_DECLS /* Workaround for #3398 */
+extern "C" /* Workaround for #3398 */
+{
 #include <hildon/hildon-color-chooser.h>
 #include <hildon/hildon-color-chooser-dialog.h>
-G_END_DECLS
-#endif
-
+}
 #include <hildon/hildon-controlbar.h>
 #include <hildon/hildon-date-editor.h>
 
@@ -67,8 +65,8 @@ int main (int argc, char *argv[])
     std::cout << get_defs(HILDON_TYPE_CAPTION)
               << get_defs(HILDON_TYPE_CALENDAR_POPUP)
               << get_defs(HILDON_TYPE_COLOR_BUTTON)
-              //<< get_defs(HILDON_TYPE_COLOR_CHOOSER)              
-              //<< get_defs(HILDON_TYPE_COLOR_CHOOSER_DIALOG)
+              << get_defs(HILDON_TYPE_COLOR_CHOOSER)              
+              << get_defs(HILDON_TYPE_COLOR_CHOOSER_DIALOG)
               << get_defs(HILDON_TYPE_CODE_DIALOG)
               << get_defs(HILDON_TYPE_DATE_EDITOR)
               << get_defs(HILDON_TYPE_FIND_TOOLBAR)
